pub struct MachoHeaderFlags(/* private fields */);Expand description
The MachoHeaderFlags flag value.
Implementations
Sourceimpl MachoHeaderFlags
impl MachoHeaderFlags
Sourcepub const NOUNDEFS: MachoHeaderFlags
pub const NOUNDEFS: MachoHeaderFlags
The NOUNDEFS flag value.
Sourcepub const INCRLINK: MachoHeaderFlags
pub const INCRLINK: MachoHeaderFlags
The INCRLINK flag value.
Sourcepub const DYLDLINK: MachoHeaderFlags
pub const DYLDLINK: MachoHeaderFlags
The DYLDLINK flag value.
Sourcepub const BINDATLOAD: MachoHeaderFlags
pub const BINDATLOAD: MachoHeaderFlags
The BINDATLOAD flag value.
Sourcepub const PREBOUND: MachoHeaderFlags
pub const PREBOUND: MachoHeaderFlags
The PREBOUND flag value.
Sourcepub const SPLIT_SEGS: MachoHeaderFlags
pub const SPLIT_SEGS: MachoHeaderFlags
The SPLIT_SEGS flag value.
Sourcepub const LAZY_INIT: MachoHeaderFlags
pub const LAZY_INIT: MachoHeaderFlags
The LAZY_INIT flag value.
Sourcepub const TWOLEVEL: MachoHeaderFlags
pub const TWOLEVEL: MachoHeaderFlags
The TWOLEVEL flag value.
Sourcepub const FORCE_FLAT: MachoHeaderFlags
pub const FORCE_FLAT: MachoHeaderFlags
The FORCE_FLAT flag value.
Sourcepub const NOMULTIDEFS: MachoHeaderFlags
pub const NOMULTIDEFS: MachoHeaderFlags
The NOMULTIDEFS flag value.
Sourcepub const NOFIXPREBINDING: MachoHeaderFlags
pub const NOFIXPREBINDING: MachoHeaderFlags
The NOFIXPREBINDING flag value.
Sourcepub const PREBINDABLE: MachoHeaderFlags
pub const PREBINDABLE: MachoHeaderFlags
The PREBINDABLE flag value.
Sourcepub const ALLMODSBOUND: MachoHeaderFlags
pub const ALLMODSBOUND: MachoHeaderFlags
The ALLMODSBOUND flag value.
Sourcepub const SUBSECTIONS_VIA_SYMBOLS: MachoHeaderFlags
pub const SUBSECTIONS_VIA_SYMBOLS: MachoHeaderFlags
The SUBSECTIONS_VIA_SYMBOLS flag value.
Sourcepub const CANONICAL: MachoHeaderFlags
pub const CANONICAL: MachoHeaderFlags
The CANONICAL flag value.
Sourcepub const WEAK_DEFINES: MachoHeaderFlags
pub const WEAK_DEFINES: MachoHeaderFlags
The WEAK_DEFINES flag value.
Sourcepub const BINDS_TO_WEAK: MachoHeaderFlags
pub const BINDS_TO_WEAK: MachoHeaderFlags
The BINDS_TO_WEAK flag value.
Sourcepub const ALLOW_STACK_EXECUTION: MachoHeaderFlags
pub const ALLOW_STACK_EXECUTION: MachoHeaderFlags
The ALLOW_STACK_EXECUTION flag value.
Sourcepub const ROOT_SAFE: MachoHeaderFlags
pub const ROOT_SAFE: MachoHeaderFlags
The ROOT_SAFE flag value.
Sourcepub const SETUID_SAFE: MachoHeaderFlags
pub const SETUID_SAFE: MachoHeaderFlags
The SETUID_SAFE flag value.
Sourcepub const NO_REEXPORTED_DYLIBS: MachoHeaderFlags
pub const NO_REEXPORTED_DYLIBS: MachoHeaderFlags
The NO_REEXPORTED_DYLIBS flag value.
Sourcepub const PIE: MachoHeaderFlags
pub const PIE: MachoHeaderFlags
The PIE flag value.
Sourcepub const DEAD_STRIPPABLE_DYLIB: MachoHeaderFlags
pub const DEAD_STRIPPABLE_DYLIB: MachoHeaderFlags
The DEAD_STRIPPABLE_DYLIB flag value.
Sourcepub const HAS_TLV_DESCRIPTORS: MachoHeaderFlags
pub const HAS_TLV_DESCRIPTORS: MachoHeaderFlags
The HAS_TLV_DESCRIPTORS flag value.
Sourcepub const NO_HEAP_EXECUTION: MachoHeaderFlags
pub const NO_HEAP_EXECUTION: MachoHeaderFlags
The NO_HEAP_EXECUTION flag value.
Sourcepub const APP_EXTENSION_SAFE: MachoHeaderFlags
pub const APP_EXTENSION_SAFE: MachoHeaderFlags
The APP_EXTENSION_SAFE flag value.
Sourcepub const NLIST_OUTOFSYNC_WITH_DYLDINFO: MachoHeaderFlags
pub const NLIST_OUTOFSYNC_WITH_DYLDINFO: MachoHeaderFlags
The NLIST_OUTOFSYNC_WITH_DYLDINFO flag value.
Sourcepub const SIM_SUPPORT: MachoHeaderFlags
pub const SIM_SUPPORT: MachoHeaderFlags
The SIM_SUPPORT flag value.
Sourcepub const IMPLICIT_PAGEZERO: MachoHeaderFlags
pub const IMPLICIT_PAGEZERO: MachoHeaderFlags
The IMPLICIT_PAGEZERO flag value.
Sourcepub const DYLIB_IN_CACHE: MachoHeaderFlags
pub const DYLIB_IN_CACHE: MachoHeaderFlags
The DYLIB_IN_CACHE flag value.
Sourceimpl MachoHeaderFlags
impl MachoHeaderFlags
Sourcepub const fn empty() -> MachoHeaderFlags
pub const fn empty() -> MachoHeaderFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> MachoHeaderFlags
pub const fn all() -> MachoHeaderFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<MachoHeaderFlags>
pub const fn from_bits(bits: u32) -> Option<MachoHeaderFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> MachoHeaderFlags
pub const fn from_bits_truncate(bits: u32) -> MachoHeaderFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> MachoHeaderFlags
pub const fn from_bits_retain(bits: u32) -> MachoHeaderFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MachoHeaderFlags>
pub fn from_name(name: &str) -> Option<MachoHeaderFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MachoHeaderFlags) -> bool
pub const fn intersects(&self, other: MachoHeaderFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: MachoHeaderFlags) -> bool
pub const fn contains(&self, other: MachoHeaderFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: MachoHeaderFlags)
pub fn insert(&mut self, other: MachoHeaderFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: MachoHeaderFlags)
pub fn remove(&mut self, other: MachoHeaderFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MachoHeaderFlags)
pub fn toggle(&mut self, other: MachoHeaderFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: MachoHeaderFlags, value: bool)
pub fn set(&mut self, other: MachoHeaderFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MachoHeaderFlags) -> MachoHeaderFlags
pub const fn intersection(self, other: MachoHeaderFlags) -> MachoHeaderFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: MachoHeaderFlags) -> MachoHeaderFlags
pub const fn union(self, other: MachoHeaderFlags) -> MachoHeaderFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: MachoHeaderFlags) -> MachoHeaderFlags
pub const fn difference(self, other: MachoHeaderFlags) -> MachoHeaderFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: MachoHeaderFlags,
) -> MachoHeaderFlags
pub const fn symmetric_difference( self, other: MachoHeaderFlags, ) -> MachoHeaderFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> MachoHeaderFlags
pub const fn complement(self) -> MachoHeaderFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MachoHeaderFlags
impl MachoHeaderFlags
Sourcepub const fn iter(&self) -> Iter<MachoHeaderFlags>
pub const fn iter(&self) -> Iter<MachoHeaderFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MachoHeaderFlags>
pub const fn iter_names(&self) -> IterNames<MachoHeaderFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.