pub struct VmProtection(/* private fields */);Expand description
The VmProtection flag value.
Implementations
Sourceimpl VmProtection
impl VmProtection
Sourcepub const READ: VmProtection
pub const READ: VmProtection
The READ flag value.
Sourcepub const WRITE: VmProtection
pub const WRITE: VmProtection
The WRITE flag value.
Sourcepub const EXECUTE: VmProtection
pub const EXECUTE: VmProtection
The EXECUTE flag value.
Sourceimpl VmProtection
impl VmProtection
Sourcepub const fn empty() -> VmProtection
pub const fn empty() -> VmProtection
Get a flags value with all bits unset.
Sourcepub const fn all() -> VmProtection
pub const fn all() -> VmProtection
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<VmProtection>
pub const fn from_bits(bits: i32) -> Option<VmProtection>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> VmProtection
pub const fn from_bits_truncate(bits: i32) -> VmProtection
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> VmProtection
pub const fn from_bits_retain(bits: i32) -> VmProtection
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<VmProtection>
pub fn from_name(name: &str) -> Option<VmProtection>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: VmProtection) -> bool
pub const fn intersects(&self, other: VmProtection) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: VmProtection) -> bool
pub const fn contains(&self, other: VmProtection) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: VmProtection)
pub fn insert(&mut self, other: VmProtection)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: VmProtection)
pub fn remove(&mut self, other: VmProtection)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: VmProtection)
pub fn toggle(&mut self, other: VmProtection)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: VmProtection, value: bool)
pub fn set(&mut self, other: VmProtection, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: VmProtection) -> VmProtection
pub const fn intersection(self, other: VmProtection) -> VmProtection
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: VmProtection) -> VmProtection
pub const fn union(self, other: VmProtection) -> VmProtection
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: VmProtection) -> VmProtection
pub const fn difference(self, other: VmProtection) -> VmProtection
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: VmProtection) -> VmProtection
pub const fn symmetric_difference(self, other: VmProtection) -> VmProtection
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> VmProtection
pub const fn complement(self) -> VmProtection
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl VmProtection
impl VmProtection
Sourcepub const fn iter(&self) -> Iter<VmProtection> ⓘ
pub const fn iter(&self) -> Iter<VmProtection> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<VmProtection> ⓘ
pub const fn iter_names(&self) -> IterNames<VmProtection> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl VmProtection
impl VmProtection
Sourcepub fn rwx_string(self) -> String
pub fn rwx_string(self) -> String
Performs rwx_string.