Bounded Objective-C method-implementation traversal.
Structs
- ObjC
Method Imp - One parsed Objective-C implementation entry.
- ObjC
Method Record - One parsed Objective-C method record with exact storage provenance.
- ObjC
Method Record Provenance - Storage and decoding provenance for one Objective-C method-list entry.
Enums
- ObjC
Method Kind - Objective-C method dispatch kind.
- ObjC
Method Record Encoding - Pointer or relative-field representation used by one method record.
- ObjC
Relative Selector Encoding - Selector representation selected by a relative method-list header.
Functions
- fold_
method_ imps - Fold class and category method implementations into caller-owned state.
- fold_
method_ imps_ from_ source - Fold method implementations from one borrowed thin Mach-O byte source.
- fold_
method_ records - Fold strict method records with exact storage and decoding provenance.
- fold_
method_ records_ from_ source - Fold strict method records from one borrowed thin Mach-O byte source.