MachoFile

Struct MachoFile 

pub struct MachoFile<'data> { /* private fields */ }
The MachoFile type.

Implementations

Source

impl<'data> MachoFile<'data>

pub fn header(&self) -> &MachoHeader

Performs header.

pub fn load_commands(&self) -> &[ParsedLoadCommand]

Performs load_commands.

pub fn segments(&self) -> &[Segment]

Performs segments.

pub fn endian(&self) -> Endian

Performs endian.

pub fn bitness(&self) -> Bitness

Performs bitness.

pub fn bytes(&self) -> &'data [u8] ⓘ

Performs bytes.

pub fn file_size(&self) -> usize

Performs file_size.

pub fn is_64bit(&self) -> bool

Performs is_64bit.

pub fn all_sections(&self) -> impl Iterator<Item = &Section>

Flat iterator over all sections across all segments.

pub fn find_load_command( &self, pred: impl Fn(&LoadCommand) -> bool, ) -> Option<&ParsedLoadCommand>

Find the first load command whose kind matches the predicate.

pub fn load_command_code( &self, command: &ParsedLoadCommand, ) -> Result<u32, ParseError>

Return the exact numeric command word retained in the input.

pub fn address_map(&self) -> &AddressMap

Performs address_map.

pub fn uuid(&self) -> Option<&[u8; 16]>

Performs uuid.

pub fn image_base(&self) -> Va

Performs image_base.

pub fn section(&self, seg_name: &str, sect_name: &str) -> Option<&Section>

Performs section.

pub fn section_bytes( &self, seg_name: &str, sect_name: &str, ) -> Result<&'data [u8], ParseError>

Performs section_bytes.

pub fn read_bytes_at( &self, offset: ThinFileOffset, len: usize, ) -> Result<&'data [u8], ParseError>

Performs read_bytes_at.

pub fn read_bytes_at_va( &self, va: Va, len: usize, ) -> Result<&'data [u8], ParseError>

Performs read_bytes_at_va.

pub fn read_bytes_at_rva( &self, rva: Rva, len: usize, ) -> Result<&'data [u8], ParseError>

Performs read_bytes_at_rva.

Source

impl<'data> MachoFile<'data>

pub fn ext<E>(&self) -> Result<E, <E as MachoExt<'data>>::Error>
where E: MachoExt<'data>,

Performs ext.