Module imp

Module imp 

Bounded Objective-C method-implementation traversal.

Structs

ObjCMethodImp
One parsed Objective-C implementation entry.
ObjCMethodRecord
One parsed Objective-C method record with exact storage provenance.
ObjCMethodRecordProvenance
Storage and decoding provenance for one Objective-C method-list entry.

Enums

ObjCMethodKind
Objective-C method dispatch kind.
ObjCMethodRecordEncoding
Pointer or relative-field representation used by one method record.
ObjCRelativeSelectorEncoding
Selector representation selected by a relative method-list header.

Functions

fold_method_imps
Fold class and category method implementations into caller-owned state.
fold_method_imps_from_source
Fold method implementations from one borrowed thin Mach-O byte source.
fold_method_records
Fold strict method records with exact storage and decoding provenance.
fold_method_records_from_source
Fold strict method records from one borrowed thin Mach-O byte source.